@@ -6,13 +6,12 @@
 """
 
 from __future__ import absolute_import
-from varnish_bans_manager.core.models.base import Model
 from django.contrib.auth.models import User
 from django.contrib.contenttypes import generic
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
-from varnish_bans_manager.core.models import Node
+from varnish_bans_manager.core.models.base import Model
 
 
 class BanSubmission(Model):
@@ -70,7 +69,7 @@ class BanSubmissionItem(Model):
         null=False
     )
     node = models.ForeignKey(
-        Node,
+        'core.Node',
         related_name='ban_submission_items',
         null=False
     )
